ProSHADE: Class Members - Functions

| ProSHADE 0.7.5.4 (MAR 2021) Protein Shape Detection

### - d -

- deepCopyMap() : ProSHADE_internal_data::ProSHADE_data
- detectSymmetryFromAngleAxisSpace() : ProSHADE_internal_data::ProSHADE_data
- detectSymmetryInStructure() : ProSHADE_internal_data::ProSHADE_data
- detectSymmetryInStructurePython() : ProSHADE_internal_data::ProSHADE_data
- determineAllSHValues() : ProSHADE_settings
- determineBandwidth() : ProSHADE_settings
- determineBandwidthFromAngle() : ProSHADE_settings
- determineIntegrationOrder() : ProSHADE_settings
- determineSphereDistances() : ProSHADE_settings